/* blas/test_cases.h
 * 
 * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


/* set of constant objects for use in tests */

#include <gsl/gsl_complex.h>

extern const float  c_2[];
extern const float  c_3[];
extern const double z_2[];
extern const double z_3[];

extern const float   vector_4_zero_f[];
extern const double  vector_4_zero_d[];

extern const float   vector_4_zero_c[];
extern const double  vector_4_zero_z[];

extern const float   vector_4_f[];
extern const double  vector_4_d[];

extern const float   vector_4_c[];
extern const double  vector_4_z[];

extern const float   matrix_gen_4_f[];
extern const double  matrix_gen_4_d[];

extern const float   matrix_t_4_f[];
extern const double  matrix_t_4_d[];

extern const float   matrix_t_4_fpu[];
extern const double  matrix_t_4_dpu[];
extern const float   matrix_t_4_fpl[];
extern const double  matrix_t_4_dpl[];


extern const float   matrix_gen_4_c[];
extern const double  matrix_gen_4_z[];

extern const float   matrix_gen_4_cpu[];
extern const double  matrix_gen_4_zpu[];
extern const float   matrix_gen_4_cpl[];
extern const double  matrix_gen_4_zpl[];


extern const float   matrix_her_4_c[];
extern const double  matrix_her_4_z[];

extern const float   matrix_her_4_cpu[];
extern const double  matrix_her_4_zpu[];
extern const float   matrix_her_4_cpl[];
extern const double  matrix_her_4_zpl[];

